@@ -3,7 +3,7 @@ package WiringPi::API;
 use strict;
 use warnings;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 require XSLoader;
 XSLoader::load('WiringPi::API', $VERSION);
@@ -234,6 +234,19 @@ Perl OO access
 
     my $api = WiringPi::API->new;
 
+    # !!!
+    # regardless of using OO or functional style, one of the C<setup*()>
+    # functions MUST be called prior to doing anything
+    # !!!
+
+    # OO
+
+    $api->setup;
+
+    # functional
+
+    setup();
+
 =head1 DESCRIPTION
 
 This is an XS-based module, and requires L<wiringPi|http://wiringpi.com> to be
@@ -288,14 +301,21 @@ Exports all available exportable functions.
 
 =head2 new()
 
+NOTE: After an object is created, one of the C<setup*> methods must be called
+to initialize the Pi board.
+
 Returns a new C<WiringPi::API> object.
 
 =head2 setup()
 
 Maps to C<int wiringPiSetup()>
 
-See L<wiringPi setup functions|http://wiringpi.com/reference/setup> for
-for information on this method.
+Sets the pin numbering scheme to C<WPI> (wiringPi numbers).
+
+Each setup function has benefits and drawbacks. Please refer to the
+L<wiringPi setup functions|http://wiringpi.com/reference/setup> for details.
+
+This one requires you to run your script as the C<root> user.
 
 Note that only one of the C<setup*()> methods can be called per program run.
 
@@ -303,8 +323,14 @@ Note that only one of the C<setup*()> methods can be called per program run.
 
 Maps to C<int wiringPiSetupSys()>
 
-See L<wiringPi setup functions|http://wiringpi.com/reference/setup> for
-for information on this method.
+Sets the pin numbering scheme to C<BCM> (Broadcom numbers).
+
+Each setup function has benefits and drawbacks. Please refer to the
+L<wiringPi setup functions|http://wiringpi.com/reference/setup> for details.
+
+This one does NOT require running as root, but you have to manually export
+the pins yourself with the C<gpio> command line utility prior to using the
+pins.
 
 Note that only one of the C<setup*()> methods can be called per program run.
 
@@ -312,8 +338,12 @@ Note that only one of the C<setup*()> methods can be called per program run.
 
 Maps to C<int wiringPiSetupPhys()>
 
-See L<wiringPi setup functions|http://wiringpi.com/reference/setup> for
-for information on this method.
+Sets the pin numbering scheme to C<PHYS> (physical board numbers).
+
+Each setup function has benefits and drawbacks. Please refer to the
+L<wiringPi setup functions|http://wiringpi.com/reference/setup> for details.
+
+This one requires you to run your script as the C<root> user.
 
 Note that only one of the C<setup*()> methods can be called per program run.
 
@@ -321,8 +351,12 @@ Note that only one of the C<setup*()> methods can be called per program run.
 
 Maps to C<int wiringPiSetupGpio()>
 
-See L<wiringPi setup functions|http://wiringpi.com/reference/setup> for
-for information on this method.
+Sets the pin numbering scheme to C<BCM> (Broadcom numbers).
+
+Each setup function has benefits and drawbacks. Please refer to the
+L<wiringPi setup functions|http://wiringpi.com/reference/setup> for details.
+
+This one requires you to run your script as the C<root> user.
 
 Note that only one of the C<setup*()> methods can be called per program run.
 
@@ -336,7 +370,8 @@ Parameters:
 
     $pin
 
-Mandatory: The GPIO pin number, using wiringPi's pin number representation.
+Mandatory: The GPIO pin number, using your currently in-use numbering scheme
+(C<BCM> aka GPIO by default).
 
     $mode
 
@@ -352,7 +387,8 @@ Parameters:
     
     $pin
 
-Mandatory: The wiringPi number representation of the GPIO pin.
+Mandatory: The GPIO pin number, using your currently in-use numbering scheme
+(C<BCM> aka GPIO by default).
 
 =head2 write_pin($pin, $state)
 
@@ -364,7 +400,8 @@ Parameters:
 
     $pin
 
-Mandatory: The wiringPi number representation of the GPIO pin.
+Mandatory: The GPIO pin number, using your currently in-use numbering scheme
+(C<BCM> aka GPIO by default).
 
     $state
 
@@ -380,7 +417,8 @@ Parameters:
 
     $pin
 
-Mandatory: The wiringPi number representation of the GPIO pin.
+Mandatory: The GPIO pin number, using your currently in-use numbering scheme
+(C<BCM> aka GPIO by default).
 
     $direction
 
@@ -396,7 +434,8 @@ Parameters:
 
     $pin
 
-Mandatory: The wiringPi number representation of the GPIO pin.
+Mandatory: The GPIO pin number, using your currently in-use numbering scheme
+(C<BCM> aka GPIO by default).
 
     $value
 
@@ -413,7 +452,8 @@ Parameters:
     
     $pin
 
-Mandatory: The wiringPi number representation of the GPIO pin.
+Mandatory: The GPIO pin number, using your currently in-use numbering scheme
+(C<BCM> aka GPIO by default).
 
 =head1 BOARD METHODS
 
@@ -434,7 +474,8 @@ Parameters:
 
     $pin_num
 
-Mandatory: The C<wiringPi> representation of a pin number.        
+Mandatory: The GPIO pin number, using your currently in-use numbering scheme
+(C<BCM> aka GPIO by default).
 
 =head2 phys_to_gpio($pin_num)
 
